==> nodejs_interop-0.7.0.tar.gz: lib/src/node/errors/system_error.dart <==
part of nodejs_interop.node;

/// Indicates that an exception occurred within the program's runtime environment.
/// Typically, these are operational errors that occur when an application violates an operating system constraint
/// such as attempting to read a file that does not exist or when the user does not have sufficient permissions.
@JS()
abstract class SystemError extends JSError {

  /// Error code indicating that an attempt was made to access a file in a way forbidden by its file access permissions.
  static const String EACCES = 'EACCES';

  /// Error code indicating that an attempt to bind a server to a local address failed
  /// due to another server on the local system already occupying that address.
  static const String EADDRINUSE = 'EADDRINUSE';

  /// Error code indicating that no connection could be made because the target machine actively refused it.
  static const String ECONNREFUSED = 'ECONNREFUSED';

  /// Error code indicating that a connection was forcibly closed by a peer.
  static const String ECONNRESET = 'ECONNRESET';

  /// Error code indicating that an existing file was the target of an operation that required that the target not exist.
  static const String EEXIST = 'EEXIST';

  /// Error code indicating that an operation expected a file, but the given pathname was a directory.
  static const String EISDIR = 'EISDIR';

  /// Error code indicating that the maximum number of file descriptors allowable on the system has been reached,
  /// and requests for another descriptor cannot be fulfilled until at least one has been closed.
  static const String EMFILE = 'EMFILE';

  /// Error code indicating that a component of the specified pathname does not exist:
  /// no entity (file or directory) could be found by the given path.
  static const String ENOENT = 'ENOENT';

  /// Error code indicating that a component of the given pathname existed, but was not a directory as expected.
  static const String ENOTDIR = 'ENOTDIR';

  /// Error code indicating that a directory with entries was the target of an operation that requires an empty directory.
  static const String ENOTEMPTY = 'ENOTEMPTY';

  /// Error code indicating that an attempt was made to perform an operation that requires elevated privileges.
  static const String EPERM = 'EPERM';

  /// Error code indicating that a write on a pipe, socket, or FIFO failed because there was no process to read the data.
  static const String EPIPE = 'EPIPE';

  /// Error code indicating that a connect or send request failed because the connected party did not properly respond after a period of time.
  static const String ETIMEDOUT = 'ETIMEDOUT';

  /// When present, the address to which the connection failed.
  external String get address;
  external set address(String value);

  /// An integer or a string.
  /// The integer is a negative value which corresponds to the error code defined in [`libuv` error handling](http://docs.libuv.org/en/v1.x/errors.html).
  /// In case of a string, it is the same as [code].
  external dynamic get errno;
  external set errno(value);

  /// When present, a relevant invalid pathname.
  external String get path;
  external set path(String value);

  /// When present, the connection's port that is not available.
  external int get port;
  external set port(int value);

  /// The [`syscall`](http://manpages.ubuntu.com/manpages/xenial/man2/syscall.2.html) that failed.
  external String get syscall;
  external set syscall(String value);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/node/errors/system_error.dart <==
part of nodejs_interop.node;

/// Indicates that an exception occurred within the program's runtime environment.
/// Typically, these are operational errors that occur when an application violates an operating system constraint
/// such as attempting to read a file that does not exist or when the user does not have sufficient permissions.
@JS()
abstract class SystemError extends JSError {

  /// Error code indicating that an attempt was made to access a file in a way forbidden by its file access permissions.
  static const String EACCES = 'EACCES'; // ignore: constant_identifier_names

  /// Error code indicating that an attempt to bind a server to a local address failed
  /// due to another server on the local system already occupying that address.
  static const String EADDRINUSE = 'EADDRINUSE'; // ignore: constant_identifier_names

  /// Error code indicating that no connection could be made because the target machine actively refused it.
  static const String ECONNREFUSED = 'ECONNREFUSED'; // ignore: constant_identifier_names

  /// Error code indicating that a connection was forcibly closed by a peer.
  static const String ECONNRESET = 'ECONNRESET'; // ignore: constant_identifier_names

  /// Error code indicating that an existing file was the target of an operation that required that the target not exist.
  static const String EEXIST = 'EEXIST'; // ignore: constant_identifier_names

  /// Error code indicating that an operation expected a file, but the given pathname was a directory.
  static const String EISDIR = 'EISDIR'; // ignore: constant_identifier_names

  /// Error code indicating that the maximum number of file descriptors allowable on the system has been reached,
  /// and requests for another descriptor cannot be fulfilled until at least one has been closed.
  static const String EMFILE = 'EMFILE'; // ignore: constant_identifier_names

  /// Error code indicating that a component of the specified pathname does not exist:
  /// no entity (file or directory) could be found by the given path.
  static const String ENOENT = 'ENOENT'; // ignore: constant_identifier_names

  /// Error code indicating that a component of the given pathname existed, but was not a directory as expected.
  static const String ENOTDIR = 'ENOTDIR'; // ignore: constant_identifier_names

  /// Error code indicating that a directory with entries was the target of an operation that requires an empty directory.
  static const String ENOTEMPTY = 'ENOTEMPTY'; // ignore: constant_identifier_names

  /// Error code indicating that an attempt was made to perform an operation that requires elevated privileges.
  static const String EPERM = 'EPERM'; // ignore: constant_identifier_names

  /// Error code indicating that a write on a pipe, socket, or FIFO failed because there was no process to read the data.
  static const String EPIPE = 'EPIPE'; // ignore: constant_identifier_names

  /// Error code indicating that a connect or send request failed because the connected party did not properly respond after a period of time.
  static const String ETIMEDOUT = 'ETIMEDOUT'; // ignore: constant_identifier_names

  /// When present, the address to which the connection failed.
  external String get address;
  external set address(String value);

  /// An integer or a string.
  /// The integer is a negative value which corresponds to the error code defined in [`libuv` error handling](http://docs.libuv.org/en/v1.x/errors.html).
  /// In case of a string, it is the same as [code].
  external dynamic get errno;
  external set errno(value);

  /// When present, a relevant invalid pathname.
  external String get path;
  external set path(String value);

  /// When present, the connection's port that is not available.
  external int get port;
  external set port(int value);

  /// The [`syscall`](http://manpages.ubuntu.com/manpages/xenial/man2/syscall.2.html) that failed.
  external String get syscall;
  external set syscall(String value);
}
